@@ -6,14 +6,15 @@ OC.L10N.register(
     "Add contacts" : "Ouzhpennañ darempredoù",
     "Loading …" : "O Kargañ ...",
     "General settings" : "Stummoù hollek",
-    "Send email" : "Kas postel",
-    "Download" : "Pellgargañ",
     "Rename" : "Adenvel",
+    "Send email" : "Kas postel",
     "Delete" : "Dilemel",
     "Copy link" : "Kopiañ al liamm",
+    "Download" : "Pellgargañ",
     "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
     "No users or groups" : "Implijourienn pe strodadoù ebet",
     "can edit" : "posuple eo embann",
+    "Add" : "Ouzhpennañ",
     "Display name" : "Anv ardivink",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
     "Save" : "Enrollañ",
@@ -23,6 +24,7 @@ OC.L10N.register(
     "Name" : "Anv",
     "Title" : "Titl",
     "Company" : "Embregerez",
+    "View profile" : "Gwelet ar profil",
     "Search contacts …" : "Klask darempred ...",
     "No results" : "Disoc'h ebet",
     "Pending" : "O c'hortoz",
@@ -34,7 +36,6 @@ OC.L10N.register(
     "Email" : "Postel",
     "Admin" : "Merour",
     "Owner" : "Perc'henner",
-    "Users" : "Implijer",
     "Website" : "Lec'hien web",
     "Location" : "Lec'hiadur",
     "Home" : "Degemer",
