@@ -10,8 +10,8 @@ OC.L10N.register(
     "Rename" : "Renombrar",
     "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
-    "Download" : "Descargar",
     "Copy link" : "Copiar liga",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
     "Add" : "Agregar",
@@ -25,9 +25,9 @@ OC.L10N.register(
     "Settings" : "Settings",
     "Cancel" : "Cancelar",
     "Invalid image" : "Imagen inválida",
+    "Address book" : "Libreta de direcciones",
     "Name" : "Nombre",
     "Title" : "Título",
-    "Address book" : "Libreta de direcciones",
     "Search contacts …" : "Buscar contactos ...",
     "No results" : "No hay resultados",
     "Pending" : "Pendiente",
@@ -76,7 +76,6 @@ OC.L10N.register(
     "Voice" : "Voz",
     "Car" : "Auto",
     "Work pager" : "Localizador de trabajo",
-    "Manager" : "Gerente",
     "Social network" : "Red social",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
@@ -95,6 +94,7 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Manager" : "Gerente"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
